require 'spec_helper'

class String
  include Workbox::Text
end

class Testie
  include Workbox::Text

  def to_s
    'testie'
  end
end

RSpec.describe Workbox::Text do
  specify "slugging a string" do
    expect('some string'.slug).to eq 'some_string'
    expect('some-string, with marks...'.slug).to eq 'some_string_with_marks'
  end

  specify "reflecting a string" do
    expect('<>'.reflect).to eq('<>')
    expect('<h1>'.reflect).to eq('<1h>')
    expect('{%'.reflect).to eq('%}')
    expect('(ss'.reflect).to eq('ss)')
    expect(']_'.reflect).to eq('_[')
  end

  specify "wrapping with characters" do
    string = 'string'
    # one matching parameter
    expect(string.wrap('{')).to eq '{string}'
    expect(string.wrap('[')).to eq '[string]'
    expect(string.wrap('(')).to eq '(string)'
    expect(string.wrap('<')).to eq '<string>'

    # one not matching parameter
    expect(string.wrap('-')).to eq '-string-'
    expect(string.wrap('**')).to eq '**string**'
    expect(string.wrap('"')).to eq %{"string"}
    expect(string.wrap("'")).to eq %{'string'}

    # two parameters
    expect(string.wrap('<h1>', '</h1>')).to eq '<h1>string</h1>'
    expect(string.wrap('{% ', ' %}')).to eq '{% string %}'
  end

  specify "wrapping custom objects with some characters" do
    testie = Testie.new
    expect(testie.wrap('{%')).to eq('{%testie%}')
  end
end
